AlertTrigger class
Constructors
- AlertTrigger({required int delay, required AlertTriggerType type, AlertProperties? props})
-
AlertTrigger.fromJson(Map<
String, dynamic> json) -
factory
Properties
- delay ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- props ↔ AlertProperties?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ AlertTriggerType
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited