CustomerPlaceAlert class

Constructors

CustomerPlaceAlert({required String uuid, required bool loan, required List<AlertLanguage> languages, required List<AlertAction> actions, required AlertProperties simpleAlert, required List<AlertTrigger> triggers, String? platform})
CustomerPlaceAlert.fromJson(Map<String, dynamic> json)
factory

Properties

actions List<AlertAction>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languages List<AlertLanguage>
getter/setter pair
loan bool
getter/setter pair
platform String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
simpleAlert AlertProperties
getter/setter pair
triggers List<AlertTrigger>
getter/setter pair
uuid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited