ConfigurationService class

Constructors

ConfigurationService({required Configuration current})

Properties

applicationType ApplicationType
getter/setter pair
current Configuration
final
hashCode int
The hash code for this object.
no setterinherited
publicationReleaseId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCurrentAppCredentials() → dynamic
isLoan() bool
isPWA() bool
isStore() bool
isStoreOffline() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited