CoreService class

Constructors

CoreService(ConfigurationService _config)

Properties

app AppService
getter/setter pair
device DeviceService
getter/setter pair
file FileService
getter/setter pair
fingerprint FingerprintService
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
network NetworkService
getter/setter pair
orientation OrientationService
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storage StorageService
getter/setter pair

Methods

instanciate() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited