StorageService class

Implemented types

Constructors

StorageService(ConfigurationService _config)

Properties

defaultStorage String
getter/setter pair
globalKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loaded bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageTables Map<String, Database>
getter/setter pair

Methods

delete(String key, [String? tableName]) Future<bool>
override
deleteAll([String? tableName]) Future<void>
override
get<T>(String key, [T fromJson(Map<String, dynamic>)?, String? tableName]) Future<T?>
Para recuperar un objeto de una clase especifica se debe pasar la factoria MyClass.fromJson de dicha clase
override
getAll<T>(String tableName, [T fromJson(Map<String, dynamic>)?]) Future<List<T>>
override
initialize() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, dynamic value, [String? tableName]) Future<bool>
Para añadir un objeto de una clase especifica se debe parsear a json con su funcion toJson()
override
setAll(String key, List values, [String? tableName]) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited