PurchaseInfo class

Constructors

PurchaseInfo({String host = "", String placeId = "", String appKey = "", String validate = "", String version = ""})

Properties

appKey String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String
getter/setter pair
placeId String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validate String
getter/setter pair
version String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validatePurchaseInfo() bool

Operators

operator ==(Object other) bool
The equality operator.
inherited