Store class

Inheritance

Constructors

Store({bool enabled = false, String clientId = "", String clientSecret = "", bool isOffline = false})

Properties

clientId String
getter/setter pairinherited
clientSecret String
getter/setter pairinherited
enabled bool
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isOffline bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited