AppFile class

Constructors

AppFile({required String uuid, required String url, WebFile? webFile, File? file})
AppFile.empty()
factory

Properties

file File?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
getter/setter pair
uuid String
getter/setter pair
webFile WebFile?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited