StorageHandler class abstract

Implementers

Constructors

StorageHandler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String key, [String? table]) Future<void>
deleteAll([String? table]) Future<void>
get<T>(String key, [T fromJson(Map<String, dynamic>)?, String? table]) Future<T?>
getAll<T>(String table, [T fromJson(Map<String, dynamic>)?]) Future<List<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, dynamic value, [String? table]) Future<void>
setAll(String key, List values, [String? table]) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited