Tables class

Constructors

Tables()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

all → const List<String>
categories → const String
clientAlerts → const String
contents → const String
downloadedTours → const String
languages → const String
logs → const String
main → const String
maps → const String
medias → const String
tours → const String
tracking → const String
webFile → const String