CustomerPlace class

Constructors

CustomerPlace({required String name, required String code, required String type, required CustomerPlaceLocation location, required bool enableStatistics, required List<CustomerPlaceCategory> categories, required List<CustomerPlaceLanguage> languages, required List<Tour> tours, required List<CustomerPlaceMap> maps, required List<CustomerPlaceContent> contents, required List<CustomerPlaceAlert> clientAlerts})
CustomerPlace.fromJson(Map<String, dynamic> json)
factory

Properties

categories List<CustomerPlaceCategory>
getter/setter pair
clientAlerts List<CustomerPlaceAlert>
getter/setter pair
code String
getter/setter pair
contents List<CustomerPlaceContent>
getter/setter pair
enableStatistics bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languages List<CustomerPlaceLanguage>
getter/setter pair
location CustomerPlaceLocation
getter/setter pair
maps List<CustomerPlaceMap>
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tours List<Tour>
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited