CustomerPlaceContent class

Constructors

CustomerPlaceContent({required String uuid, required TemplateKeys templateKey, required List<CustomerPlaceCategory> categories, required dynamic template, required List<String> locators, String keyboardCode = '', bool isChild = false})
CustomerPlaceContent.empty()
factory
CustomerPlaceContent.fromJson(Map<String, dynamic> json)
factory

Properties

categories List<CustomerPlaceCategory>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isChild bool
getter/setter pair
keyboardCode String
getter/setter pair
locators List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
template ↔ dynamic
getter/setter pair
templateKey TemplateKeys
getter/setter pair
uuid String
getter/setter pair

Methods

getTemplate<T extends Template>() → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited