DomainService class

Constructors

DomainService(ConfigurationService _config, CoreService _core)

Properties

accessibility AccessibilityService
final
contents ContentService
latefinal
downloader DownloaderService
latefinal
hashCode int
The hash code for this object.
no setterinherited
languages LanguageService
latefinal
loader LoaderService
latefinal
maps MapService
latefinal
purchase PurchaseService
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tours TourService
latefinal
tracking TrackingService
latefinal
tree TreeService
latefinal
ventour VentourService
latefinal

Methods

getPipes() PipeService
instanciate() → void
loadOnMemory() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited