DownloaderService class
Constructors
- DownloaderService(FileService _file, StorageService _storage, DownloaderUtilsService _utils, DownloaderStatusService status)
Properties
- contentsDownloaded ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
progress
↔ EventEmitter<
double> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → DownloaderStatusService
-
final
Methods
-
download(
DownloadedTourStatus downloadedTourStatus, [bool accessibility = false]) → Future< bool> -
downloadAll(
) → Future< bool> -
modifyDownloadedLanguageStatus(
DownloadedTourStatus downloadedTourStatus) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setContentsDownloaded(
String tourUuid, [bool accessibility = false]) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited