DownloaderStatusService class

Properties

downloadedLanguageStatus DownloadedLanguageStatus
no setter
hashCode int
The hash code for this object.
no setterinherited
onDownloadedLanguageStatudChanged EventEmitter<DownloadedLanguageStatus>
getter/setter pair
progress double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canDownloadTours() bool
clearDownloadedLanguageStatus() → dynamic
downloadMediaList([String? tourUuid]) Future<List>
getAllTourMedias() Future<DownloadedLanguageStatus>
getDownloadedTourStatus(String tourUuid) DownloadedTourStatus?
initialize() → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
splitTourAccessibilityMedias(List medias) List<List>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited