LanguageService class

Constructors

LanguageService(StorageService _storage)

Properties

all List<CustomerPlaceLanguage>
getter/setter pair
current CustomerPlaceLanguage
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
main CustomerPlaceLanguage
getter/setter pair
onLanguageChange EventEmitter<CustomerPlaceLanguage>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkCurrentLoaded() bool
clearCurrent() → void
initialize() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrent(CustomerPlaceLanguage language) → void
stringToLocale(String isoCode) Locale
Separa el isoCode para crear un objeto de tipo Locale
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited