LoaderService class
Constructors
- LoaderService(StorageService _storage)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteAll(
) → Future< void> -
fromJson(
Map< String, dynamic> json) → Future<bool> -
fromRequest(
Map< String, dynamic> publicationRelease) → Future<bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveAll(
Map< String, dynamic> publicationRelease) → Future<bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited