TourService class

Constructors

TourService(TreeService _tree, LanguageService _language, StorageService _storage)

Properties

current CurrentTour
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
list List<Tour>
getter/setter pair
onCurrentChange EventEmitter<Tour>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanCurrent() → void
getAccessibility(Tour tour) AccessibilityConfiguration
hasAccessibility(Tour tour) bool
loadAll() Future<void>
loadToursList() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrent(Tour tour) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited