TrackingCreatorService class

Constructors

TrackingCreatorService(AppService _app, ConfigurationService _config, LanguageService _language, DeviceService _device, ScreenTimeService _screen, StorageService _storage)

Properties

counter int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onCounterChanged EventEmitter<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appClosed() → void
appOpen() → void
clientAlertClosed(String clientAlertUuid) → void
contentAccess(String contentUuid, String mode) → void
contentViewed(String contentUuid) → void
createInteraction() Interaction
endVisit() → void
floatingSignLanguage(String mediaResourceUuid, String action, int x, int y, bool resized) → void
fullscreenMode(String widgetUuid) → void
gps(double latitude, double longitude, double altitude) → void
keyboardSearch(String value, bool found) → void
languageSelected(String isoCode) → void
mapViewed(String mapUuid) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optionSelected(String widgetUuid, int option) → void
phoneCharging() → void
playerMedia(String mediaResourceUuid, String action) → void
purchaseCode(String code, bool validated) → void
resizeText(String widgetUuid, int from, int to) → void
slide(String widgetUuid, int from, int to) → void
startVisit() → void
toString() String
A string representation of this object.
inherited
tourAccess(String tourUuid, AccessibilityConfiguration tourAccessibility) → void
zoomImage(String mediaResourceUuid) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited