TrackingService class
Constructors
- TrackingService(ConfigurationService _config, AuthService _auth, DeviceService _device, FingerprintService _fingerprint, StorageService _storage, ScreenTimeService screen, TrackingCreatorService creator)
Properties
- creator → TrackingCreatorService
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
retryInteractions
↔ List<
Map< String, dynamic> > -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screen → ScreenTimeService
-
final
Methods
-
chunkInteractions(
List< Map< interactions) → List<String, dynamic> >List< Map< >String, dynamic> > -
deleteAll(
) → void -
deleteLastAppClosed(
) → Future< bool> -
listenToSend(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prepareAndSend(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited