TreeService class

Constructors

TreeService(LanguageService _language)

Properties

allTourNodes List<TreeNode>
getter/setter pair
currentChildrenNodes List<TreeNode>
getter/setter pair
currentNode TreeNode
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tourChildrenNodes List<TreeNode>
getter/setter pair
tourTreeNode TreeNode
getter/setter pair

Methods

cleanCurrentNode() → void
findParentContentUuidFromChild(TreeNode parentNode, String childContentUuid) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCurrentNode({String? contentUuid, TreeNode? treeNode}) → void
setTourChildrenNodes(String contentUuid) → void
setTourTreeNode(TreeNode treeNode) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited