DownloadedTourStatus class
Constructors
- DownloadedTourStatus({required DownloadedMediaStatus tourStatus, required String tourUuid, DownloadedMediaStatus? accessibilityStatus})
- DownloadedTourStatus.empty([String? tourUuid])
-
factory
-
DownloadedTourStatus.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessibilityStatus ↔ DownloadedMediaStatus?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tourStatus ↔ DownloadedMediaStatus
-
getter/setter pair
- tourUuid ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited