MediaResourceAudio class

Inheritance

Constructors

MediaResourceAudio({required String uuid, required MediaResourceType type, required FileUploaded file})
MediaResourceAudio.empty()
factory
MediaResourceAudio.fromJson(Map<String, dynamic> json)
factory

Properties

file FileUploaded
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MediaResourceType
getter/setter pairinherited
uuid String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited