MediaResourceVideo class

Inheritance

Constructors

MediaResourceVideo({required String uuid, required MediaResourceType type, required FileUploaded defaultProp, required FileUploaded small, required FileUploaded poster})
MediaResourceVideo.empty()
factory
MediaResourceVideo.fromJson(Map<String, dynamic> json)
factory

Properties

defaultProp FileUploaded
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
poster FileUploaded
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small FileUploaded
getter/setter pair
type MediaResourceType
getter/setter pairinherited
uuid String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited