TreeNode class
Constructors
-
TreeNode({required String uuid, required int position, required bool interactive, required String displayMode, required List<
TreeNodeLanguageExclusion> languageExclusion, String? contentUuid, String? keyboardCode, List<TreeNode> ? children}) - TreeNode.empty()
-
factory
-
TreeNode.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
↔ List<
TreeNode> ? -
getter/setter pair
- contentUuid ↔ String?
-
getter/setter pair
- displayMode ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interactive ↔ bool
-
getter/setter pair
- keyboardCode ↔ String?
-
getter/setter pair
-
languageExclusion
↔ List<
TreeNodeLanguageExclusion> -
getter/setter pair
- position ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited