PropertyAccessibleInformation class
Constructors
-
PropertyAccessibleInformation({required String uuid, required PropertyContent<
MediaResourceAudio> locution, required PropertyContent<MediaResourceVideo> signLanguage, required PropertyContent<MediaResourceRichText> subtitles, required PropertyContent<MediaResourceAudio> audioDescription, int? position}) -
PropertyAccessibleInformation.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
audioDescription
↔ PropertyContent<
MediaResourceAudio> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locution
↔ PropertyContent<
MediaResourceAudio> -
getter/setter pair
- position ↔ int?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signLanguage
↔ PropertyContent<
MediaResourceVideo> -
getter/setter pair
-
subtitles
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- uuid ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited