PropertyAlert class
Constructors
-
PropertyAlert({required String uuid, required PropertyContent<
MediaResourceImage> image, required PropertyContent<MediaResourceRichText> headerText, required PropertyContent<MediaResourceRichText> messageText, required PropertyContent<MediaResourceRichText> buttonText, int? position}) -
PropertyAlert.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
-
image
↔ PropertyContent<
MediaResourceImage> -
getter/setter pair
-
messageText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- position ↔ int?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited