PropertyBasicInformation class
Constructors
-
PropertyBasicInformation({required String uuid, required PropertyContent<
MediaResourceRichText> title, PropertyContent<MediaResourceRichText> ? subtitle, PropertyContent<MediaResourceRichText> ? paragraph, PropertyContent<MediaResourceRichText> ? location, required PropertyContent<MediaResourceImage> coverImage, int? position}) -
PropertyBasicInformation.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
coverImage
↔ PropertyContent<
MediaResourceImage> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
location
↔ PropertyContent<
MediaResourceRichText> ? -
getter/setter pair
-
paragraph
↔ PropertyContent<
MediaResourceRichText> ? -
getter/setter pair
- position ↔ int?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subtitle
↔ PropertyContent<
MediaResourceRichText> ? -
getter/setter pair
-
title
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- uuid ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited