PropertyContent<T extends MediaResource> class
Constructors
-
PropertyContent({required Map<
String, T> languages, Map<String, dynamic> ? attributes}) - PropertyContent.empty()
-
factory
-
PropertyContent.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
attributes
↔ Map<
String, dynamic> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
languages
↔ Map<
String, T> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getMediaResource(
String isoCode) → T -
getType(
) → MediaResourceType -
Available on PropertyContent<
MediaResource> , provided by the PropertyType extension -
getUuid(
) → String -
Available on PropertyContent<
MediaResource> , provided by the PropertyUuid extension -
mainTranslateRichText(
) → String -
Available on PropertyContent<
MediaResourceRichText> , provided by the MainTranslatePropertyPipe extension -
mediaResource(
{MediaResourceFields? field, MediaResourceType? mimetype, bool mainLanguage = false}) → AppFile -
Available on PropertyContent<
MediaResourceAudio> , provided by the MediaResourceAudioPipe extension -
mediaResource(
{MediaResourceFields? field, MediaResourceType? mimetype, bool mainLanguage = false}) → AppFile -
Available on PropertyContent<
MediaResourceFile> , provided by the MediaResourceFilePipe extension -
mediaResource(
{MediaResourceFields? field, MediaResourceType? mimetype, bool mainLanguage = false}) → AppFile -
Available on PropertyContent<
MediaResourceImage> , provided by the MediaResourceImagePipe extension -
mediaResource(
{MediaResourceFields? field, MediaResourceType? mimetype, bool mainLanguage = false}) → AppFile -
Available on PropertyContent<
MediaResourceVideo> , provided by the MediaResourceVideoPipe extension -
mimetype(
[MediaResourceFields field = MediaResourceFields.defaultField]) → String -
Available on PropertyContent<
MediaResourceAudio> , provided by the MimetypeAudioPipe extension -
mimetype(
[MediaResourceFields field = MediaResourceFields.defaultField]) → String -
Available on PropertyContent<
MediaResourceFile> , provided by the MimetypeFilePipe extension -
mimetype(
[MediaResourceFields field = MediaResourceFields.defaultField]) → String -
Available on PropertyContent<
MediaResourceImage> , provided by the MimetypeImagePipe extension -
mimetype(
[MediaResourceFields field = MediaResourceFields.defaultField]) → String -
Available on PropertyContent<
MediaResourceVideo> , provided by the MimetypeVideoPipe extension -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
translateRichText(
) → String -
Available on PropertyContent<
MediaResourceRichText> , provided by the TranslatePropertyPipe extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited