PropertyGame class

Inheritance

Constructors

PropertyGame({required String uuid, required PropertyContent<MediaResourceRichText> description, int? position})
PropertyGame.fromJson(Map<String, dynamic> json)
factory

Properties

description PropertyContent<MediaResourceRichText>
getter/setter pair
duration Duration
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
position int?
getter/setter pairinherited
puntuation int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited