PropertyQuestion class
Constructors
-
PropertyQuestion({required String uuid, required PropertyContent<
MediaResourceAudio> questionLocution, required PropertyContent<MediaResourceAudio> locutionRightAnswered, required PropertyContent<MediaResourceAudio> locutionWrongAnswered, required PropertyContent<MediaResourceRichText> questionText, required PropertyContent<MediaResourceRichText> helpQuestionText, required PropertyContent<MediaResourceRichText> rightAnsweredText, required PropertyContent<MediaResourceRichText> wrongAnsweredText, int? position}) -
PropertyQuestion.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
helpQuestionText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
-
locutionRightAnswered
↔ PropertyContent<
MediaResourceAudio> -
getter/setter pair
-
locutionWrongAnswered
↔ PropertyContent<
MediaResourceAudio> -
getter/setter pair
- position ↔ int?
-
getter/setter pairinherited
-
questionLocution
↔ PropertyContent<
MediaResourceAudio> -
getter/setter pair
-
questionText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
-
rightAnsweredText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid ↔ String
-
getter/setter pairinherited
-
wrongAnsweredText
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited