TemplateGameImageDifferences class

Inheritance

Constructors

TemplateGameImageDifferences({required PropertyBasicInformation basicInformation, required PropertyGameHeaderTexts gameHeaderTexts, required PropertyImagesBetweenDifferences imagesBetweenDifferences, required PropertyGame gameProperties})
TemplateGameImageDifferences.fromJson(Map<String, dynamic> json)
factory

Properties

accessibleInformation PropertyAccessibleInformation?
getter/setter pairoverride-getter
basicInformation PropertyBasicInformation
getter/setter pairoverride-getter
gameHeaderTexts PropertyGameHeaderTexts
getter/setter pair
gameProperties PropertyGame?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
imagesBetweenDifferences PropertyImagesBetweenDifferences
getter/setter pair
isGame bool
getter/setter pairinherited-setteroverride-getter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited