TemplateHotspotImage class

Inheritance

Constructors

TemplateHotspotImage({required PropertyAccessibleInformation accessibleInformation, required PropertyBasicInformation basicInformation, required PropertyHotspotImage hotspotImage, required List<PropertyHotspotInformation> hotspotInformation})
TemplateHotspotImage.fromJson(Map<String, dynamic> json)
factory

Properties

accessibleInformation PropertyAccessibleInformation
final
basicInformation PropertyBasicInformation
final
gameProperties PropertyGame?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
hotspotImage PropertyHotspotImage
getter/setter pair
hotspotInformation List<PropertyHotspotInformation>
getter/setter pair
isGame bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited