TemplateSingleImage class

Inheritance

Constructors

TemplateSingleImage({required PropertyAccessibleInformation accessibleInformation, required PropertyBasicInformation basicInformation, required PropertySingleImage singleImage})
TemplateSingleImage.fromJson(Map<String, dynamic> json)
factory

Properties

accessibleInformation PropertyAccessibleInformation
getter/setter pairoverride-getter
basicInformation PropertyBasicInformation
getter/setter pairoverride-getter
gameProperties PropertyGame?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isGame bool
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleImage PropertySingleImage
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited