AccessibilityConfiguration class

Constructors

AccessibilityConfiguration({required String languageIsoCode, required bool enableAudioDescription, required bool enableSignLanguage, required bool enableSubtitles})
AccessibilityConfiguration.empty()
AccessibilityConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

enableAudioDescription bool
getter/setter pair
enableSignLanguage bool
getter/setter pair
enableSubtitles bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languageIsoCode String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited