Tour class

Constructors

Tour({required String uuid, required int position, required int minutesDuration, required int totalContents, required PropertyCard card, required NavigationTree navigationTree, required List<String> mapsUuids, required List<AccessibilityConfiguration> accessibilityConfiguration})
Tour.empty()
factory
Tour.fromJson(Map<String, dynamic> json)
factory

Properties

accessibilityConfiguration List<AccessibilityConfiguration>
getter/setter pair
card PropertyCard
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mapsUuids List<String>
getter/setter pair
minutesDuration int
getter/setter pair
getter/setter pair
position int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalContents int
getter/setter pair
uuid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited