FloatingSignLanguage class

Inheritance

Constructors

FloatingSignLanguage({required Interaction interaction, required String mediaResourceUuid, required bool resized, required String action, required int x, required int y})
FloatingSignLanguage.fromJson(Map<String, dynamic> json)
factory

Properties

action String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interaction Interaction
getter/setter pairoverride-getter
mediaResourceUuid String
getter/setter pair
resized bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited