OptionSelected class

Inheritance

Constructors

OptionSelected({required Interaction interaction, required String widgetUuid, required int option, required int timeElapsed})
OptionSelected.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
interaction Interaction
getter/setter pairoverride-getter
option int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeElapsed int
getter/setter pair
type String
getter/setter pair
widgetUuid String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited