FileService class
Constructors
- FileService(ConfigurationService _config)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDirectory(
String path) → Future< Directory> -
deleteDirectory(
String path) → Future< FileSystemEntity> -
getFile(
String path) → AppFile -
initialize(
) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readDirectory(
String path) → List< FileSystemEntity> -
setFile(
String path, dynamic data) → Future< bool> - path completo con nombre del fichero
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- baseDirectory ↔ Directory?
-
getter/setter pair