Logger class
Constructors
- Logger()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deleteAll(
) → dynamic -
error(
dynamic error, String className, String functionName, [String? message]) → dynamic -
getAll(
) → Future< List< Log> > -
initialize(
ConfigurationService config) → dynamic -
log(
String message, String className, String functionName) → dynamic -
setStorage(
StorageService value) → dynamic