ContentService class
Constructors
- ContentService(TreeService _tree, StorageService _storage)
Properties
-
all
↔ List<
CustomerPlaceContent> -
getter/setter pair
- current ↔ CustomerPlaceContent
-
getter/setter pair
-
currentChildren
↔ List<
CustomerPlaceContent> -
getter/setter pair
-
flattenedTourChildren
↔ List<
CustomerPlaceContent> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onCurrentChange
↔ EventEmitter<
CustomerPlaceContent> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tourContents
↔ List<
CustomerPlaceContent> -
getter/setter pair
Methods
-
clearContent(
) → void -
getAccessibilityInformationFromAllContents(
) → List< PropertyAccessibleInformation> -
getAllContentsFromAllByTemplate(
TemplateKeys templateKey) → List< CustomerPlaceContent> -
getAllGames(
) → List< CustomerPlaceContent> -
getContentById(
String uuid, {bool searchInFlattened = false}) → CustomerPlaceContent? -
getContentByKeyboard(
String keyboardCode, {bool searchInFlattened = false}) → CustomerPlaceContent? -
getContentByTemplate(
TemplateKeys templateKey, {bool searchInFlattened = false}) → CustomerPlaceContent? -
getContentFromAllById(
String uuid) → CustomerPlaceContent? -
getContentFromAllByKeyboard(
String keyboardCode) → CustomerPlaceContent? -
getContentFromAllByTemplate(
TemplateKeys templateKey) → CustomerPlaceContent? -
getContentsFromTreeNodes(
List< TreeNode> children, {bool flattened = false}) → List<CustomerPlaceContent> -
loadAll(
) → Future< void> -
loadContentChildrens(
) → void -
loadTourContents(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrent(
CustomerPlaceContent content) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited