DownloaderUtilsService class
Constructors
- DownloaderUtilsService(ConfigurationService _config, ContentService _contents, LanguageService _languages, StorageService _storage)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkMediaIsDownloaded(
Map< String, dynamic> media) → Future<bool> -
createDownloadedMediaStatus(
List medias) → DownloadedMediaStatus -
createDownloadedTourStatus(
String uuid, List medias, [List? accessibility]) → DownloadedTourStatus -
filterMediasToDownload(
List medias) → Future< List> -
getAllAccessibilityMedias(
) → List -
getDownloadedLanguageStatus(
) → Future< DownloadedLanguageStatus?> -
getFilename(
String filePath) → String -
getFilePath(
String url) → String -
getMediasSize(
List medias) → int -
getMediaUrls(
Map< String, dynamic> media) → List<String> -
getTranslatedMediaResource(
PropertyContent property) → MediaResource? -
isDownloaded(
String filename) → Future< bool> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publicationReleaseHasChanged(
String publicationReleasedUuid) → Future< bool> -
setDownloadedLanguageStatus(
DownloadedLanguageStatus downloadedLanguageStatus) → Future -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited