MapService class
Constructors
- MapService(TourService _tour, StorageService _storage)
Properties
- current ↔ CustomerPlaceMap
-
getter/setter pair
- currentFloor ↔ int
-
getter/setter pair
- currentIndexFloor ↔ int
-
getter/setter pair
-
currentMapContents
↔ List<
MapContent> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tourMaps
↔ List<
CustomerPlaceMap> -
getter/setter pair
Methods
-
getCurrentName(
) → String -
getMapContentIndex(
String contentUuid) → int -
loadAll(
) → Future< void> -
loadTourMaps(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCurrentFloor(
int floor) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited