PipeService class
Constructors
- PipeService(ConfigurationService _config, FileService _file, DownloaderService _downloader, LanguageService _language)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAppFileFromFileUploaded(
String uuid, FileUploaded fileUploaded, MediaResourceType type) → AppFile -
getAppFileFromMediaResource(
MediaResource mediaResource) → AppFile -
getDownloadedMediaResource<
T extends MediaResource> (PropertyContent< T> property, [MediaResourceFields? field, MediaResourceType? mimetype, bool mainLanguage = false]) → AppFile -
getDownloadedMediaResourceField(
MediaResource mediaResource, [MediaResourceFields field = MediaResourceFields.defaultField, MediaResourceType? mimetype]) → AppFile -
getMainTranslateRichText(
PropertyContent< MediaResourceRichText> property) → String -
getMediaResource<
T extends MediaResource> (PropertyContent< T> property) → MediaResource -
getMimetype<
T extends MediaResource> (PropertyContent< T> property, [MediaResourceFields field = MediaResourceFields.defaultField]) → String -
getTranslatedMediaResource<
T extends MediaResource> (PropertyContent< T> property, [bool mainLanguage = false]) → T? -
getTranslatedRichText(
PropertyContent< MediaResourceRichText> property) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited