PurchaseService class
Constructors
- PurchaseService(ConfigurationService _config, AppService _app, DeviceService _device, StorageService _storage)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
no setter
- production ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canAccess(
) → bool -
checkIsProduction(
) → Future< bool> -
initialize(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openModal(
Widget widget) → Future< void> -
setCode(
String value) → void -
toString(
) → String -
A string representation of this object.
inherited
-
validate(
String code) → Future< bool>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited