TrackingCreatorService class
Methods
-
appClosed()
→ void
-
-
appOpen()
→ void
-
-
clientAlertClosed(String clientAlertUuid)
→ void
-
-
contentAccess(String contentUuid, String mode)
→ void
-
-
contentViewed(String contentUuid)
→ void
-
-
createInteraction()
→ Interaction
-
-
endVisit()
→ void
-
-
floatingSignLanguage(String mediaResourceUuid, String action, int x, int y, bool resized)
→ void
-
-
fullscreenMode(String widgetUuid)
→ void
-
-
gps(double latitude, double longitude, double altitude)
→ void
-
-
keyboardSearch(String value, bool found)
→ void
-
-
languageSelected(String isoCode)
→ void
-
-
mapViewed(String mapUuid)
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
optionSelected(String widgetUuid, int option)
→ void
-
-
phoneCharging()
→ void
-
-
playerMedia(String mediaResourceUuid, String action)
→ void
-
-
purchaseCode(String code, bool validated)
→ void
-
-
resizeText(String widgetUuid, int from, int to)
→ void
-
-
slide(String widgetUuid, int from, int to)
→ void
-
-
startVisit()
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
tourAccess(String tourUuid, AccessibilityConfiguration tourAccessibility)
→ void
-
-
zoomImage(String mediaResourceUuid)
→ void
-