DownloadedLanguageStatus class
Constructors
-
DownloadedLanguageStatus({required String publicationReleasedUuid, required List<
DownloadedTourStatus> tourStatus, required DownloadedMediaStatus allStatus}) - DownloadedLanguageStatus.empty()
-
factory
-
DownloadedLanguageStatus.fromJson(Map<
String, dynamic> json) -
factory
Properties
- allStatus ↔ DownloadedMediaStatus
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicationReleasedUuid ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tourStatus
↔ List<
DownloadedTourStatus> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited