AppGame class
Constructors
- AppGame({required String uuid, required void clearGame(), Duration duration = const Duration(minutes: 2), int puntuation = 100, AppGameStatus status = AppGameStatus.waiting, Duration spendedTime = Duration.zero})
- AppGame.empty()
-
factory
Properties
- clearGame → void Function()
-
final
- duration ↔ Duration
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- puntuation ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spendedTime ↔ Duration
-
getter/setter pair
- status ↔ AppGameStatus
-
getter/setter pair
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSpendedTime(
int secondsRemaining) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited