AppGamePuntuation class
Constructors
- AppGamePuntuation({required String uuid})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
playedGames
↔ List<
AppGame> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalGames ↔ int
-
getter/setter pair
- totalPuntuation ↔ int
-
getter/setter pair
- uuid → String
-
final
Methods
-
addGame(
AppGame game) → void -
currentPuntuation(
) → int -
currentScoreLevel(
) → AppGameScoreLevel -
currentSpendedTime(
) → int -
gameWasPlayed(
String gameUuid) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeGame(
AppGame game) → void -
setTotalPuntuation(
List< CustomerPlaceContent> contents) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clear(
) → void