PropertyCard class
Constructors
-
PropertyCard({required String uuid, required PropertyContent<
MediaResourceImage> defaultImage, required PropertyContent<MediaResourceRichText> title, required PropertyContent<MediaResourceRichText> description, required PropertyContent<MediaResourceRichText> confirmationMessage, int? position}) - PropertyCard.empty()
-
factory
-
PropertyCard.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
confirmationMessage
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
-
defaultImage
↔ PropertyContent<
MediaResourceImage> -
getter/setter pair
-
description
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ int?
-
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
title
↔ PropertyContent<
MediaResourceRichText> -
getter/setter pair
- uuid ↔ String
-
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited