TemplateKeys enum
Values
- ar_location_list_template → const TemplateKeys
- ar_model_template → const TemplateKeys
- carousel_images_template → const TemplateKeys
- comparison_images_template → const TemplateKeys
- content_list_template → const TemplateKeys
- game_images_differences_template → const TemplateKeys
- game_join_concepts_template → const TemplateKeys
- game_puzzle_template → const TemplateKeys
- hotspot_image_template → const TemplateKeys
- hotspot_panoramic_video_template → const TemplateKeys
- information_screen_template → const TemplateKeys
- location_list_template → const TemplateKeys
- panoramic_video_template → const TemplateKeys
- panoramic_view_template → const TemplateKeys
- quiz_template → const TemplateKeys
- single_image_template → const TemplateKeys
- video_template → const TemplateKeys
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TemplateKeys> - A constant List of the values in this enum, in order of their declaration.