Interaction class
Constructors
Properties
- customerPlaceCode → String
-
final
- date → String
-
final
- fingerprint ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier ↔ String?
-
getter/setter pair
- languageIsoCode → String
-
final
- loan ↔ bool?
-
getter/setter pair
- platform → String
-
final
- publicationReleasedUuid → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited