TourAccess class
Constructors
- TourAccess({required Interaction interaction, required String tourUuid, required bool enableSignLanguageSelected, required bool enableSubtitlesSelected, required bool enableAudioDescriptionSelected, required int timeElapsed})
-
TourAccess.fromJson(Map<
String, dynamic> json) -
factory
Properties
- enableAudioDescriptionSelected ↔ bool
-
getter/setter pair
- enableSignLanguageSelected ↔ bool
-
getter/setter pair
- enableSubtitlesSelected ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction ↔ Interaction
-
getter/setter pairoverride-getter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeElapsed ↔ int
-
getter/setter pair
- tourUuid ↔ String
-
getter/setter pair
- type ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited