TrackingTypes class abstract

Constructors

TrackingTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appClosed → const String
appOpen → const String
clientAlertClosed → const String
contentAccess → const String
contentViewed → const String
endVisit → const String
floatingSignLanguage → const String
fullscreenMode → const String
gps → const String
keyboardSearch → const String
languageSelected → const String
mapViewed → const String
optionSelected → const String
phoneCharging → const String
playerMedia → const String
purchaseCode → const String
resizeText → const String
slide → const String
startVisit → const String
tourAccess → const String
zoomImage → const String